# Basic Elements

## Paragraph

Quick fox jumps over the lazy dog

## Lists

- First item
- Second item
- Third item

## Links

nMdmail on Github

## Code

Syntax hightlighting is not supported yet.

Code Block

    def echo(word):
        print(word)

Inline `code` is supported.

## Tables

This table is from Markdown Cheatcheet by Adam

Tables | Are | Cool
--- | --- | ---
col 3 is | right-aligned | $1600
col 2 is | centered | $12
zebra stripes | are neat | $1

# Inline Images

Using local images is supported. Path specified in Markdown should be either absolute path or path relative to the location of Markdown file.